LIBRARY ieee;
USE ieee.std_logic_1164.ALL;
USE ieee.STD_LOGIC_UNSIGNED.ALL;
USE work.ImPack.ALL;

-------------------------------------------------------------------------------

ENTITY ImWriteE IS
  PORT (Reset    : IN  std_logic;       -- Reset, low-aktiv
        PixCam   : IN  std_logic_vector(7 DOWNTO 0);  -- Daten von Kamera
        HSyncCam : IN  std_logic;       -- Hsync von Kamera
        VSyncCam : IN  std_logic;       -- Vsync von Kamera
        PClk     : IN  std_logic;       -- Pixelclock von Kamera
        ClkW     : OUT std_logic;       -- ClkW fuer Ram
        AddrW    : OUT std_logic_vector(CDepth-1 DOWNTO 0);   -- RAM-Adresse a
        PixW     : OUT std_logic_vector(CWidth-1 DOWNTO 0));  -- Daten Ram
END ImWriteE;

-------------------------------------------------------------------------------
ARCHITECTURE ImWriteA OF ImWriteE IS
signal PixCam2 : std_logic_vector(15 downto 0);
signal ClkW_S : std_logic := '1';
signal AddrWS : std_logic_vector(CDepth-1 DOWNTO 0) := (others => '0');
BEGIN

RamData: process (PClk, PixCam, Reset) is
begin
	if Reset = '0' then
		PixCam2 <= (others => '0');
	elsif rising_edge(PClk) then
		PixCam2 <= PixCam & PixCam2(15 downto 8);
	end if;
end process;

RamClock: process (PClk) is
begin
	if falling_edge(PClk) then
		ClkW_S <= not ClkW_S;
	end if;
end process;

RamAddr: process (ClkW_S) is
begin
	if rising_edge(ClkW_S) then
		AddrWS <= AddrWS + 1 ;
		if AddrWS = (ChData*CvData)-1 then
			AddrWS <= (others => '0');
		end if;
	end if;
end process;

PixW <= PixCam2(15 downto 12) & PixCam2 (10 downto 7) & PixCam2(4 downto 1);
ClkW <= ClkW_S;
AddrW <= AddrWS;
END ImWriteA;

-------------------------------------------------------------------------------
